@@ -1,7 +1,6 @@
-".koUnit" <-
-function (cmd, warn = FALSE, ...)
+.koUnit <- function (cmd, warn = FALSE, ...)
 {
-	# Look if koCmd() exists, otherwise, we are probably not connected to Komodo
+	## Look if koCmd() exists, otherwise, we are probably not connected to Komodo
 	if (exists("koCmd", mode = "function")) {
 		res <- get("koCmd")(cmd, ...)
 		if (isTRUE(warn) & inherits(res, "try-error"))
@@ -13,36 +12,29 @@ function (cmd, warn = FALSE, ...)
 	}
 }
 
-"koUnit_isAutoTest" <-
-function ()
+koUnit_isAutoTest <- function ()
 {
 	res <- .koUnit('sv.socket.serverWrite(sv.r.unit.isAutoTest());')
 	return(res == "true")
 }
 
-"koUnit_setAutoTest" <-
-function (state)
+koUnit_setAutoTest <- function (state)
 {
 	if (isTRUE(state)) state <- "true" else state <- "false"
 	res <- .koUnit('sv.r.unit.setAutoTest(<<<data>>>);', data = state)
 }
 
-"koUnit_runTest" <-
-function ()
-{
+koUnit_runTest <- function ()
 	res <- .koUnit('sv.r.unit.runTest();')
-}
 
-"koUnit_showRUnitPane" <-
-function (state)
+koUnit_showRUnitPane <- function (state)
 {
 	if (missing(state)) state <- ""
 	else if (isTRUE(state)) state <- "true" else state <- "false"
 	res <- .koUnit('sv.r.unit.showRUnitPane(<<<data>>>);', data = state)
 }
 
-"koUnit_version" <-
-function ()
+koUnit_version <- function ()
 {
 	res <- .koUnit('sv.socket.serverWrite(sv.r.unit.version + "." + sv.r.unit.release);')
 	return(res)
